@@ -875,9 +875,7 @@ class InfiniteContext:
                         exclusion_path = temporary_file_directory+image_name+extension
                         text += self.getTextsFromImage(file_path=exclusion_path, use_api=use_api, language=language)+'\n\n'
                         try:
-                            if len(exclusion_path) > 0 and self.__path.exists(exclusion_path):
-                                self.__remove(exclusion_path)
-                                print(page_index)
+                            if len(exclusion_path) > 0 and self.__path.exists(exclusion_path): self.__remove(exclusion_path)
                         except: pass
                     return text
                 for page_index in range(number_of_pages):
